Type Definition tea_tapp_common::TimestampShort
source · pub type TimestampShort = i64;Expand description
Short format of timestamp (from chrono timestamp), to distinguish between transactions that may send multiple times
pub type TimestampShort = i64;Short format of timestamp (from chrono timestamp), to distinguish between transactions that may send multiple times